==> polarion_rest_api_client-1.2.0-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/workitem_comments_list_get_response_data_item_attributes_text.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.workitem_comments_list_get_response_data_item_attributes_text_type import (
    WorkitemCommentsListGetResponseDataItemAttributesTextType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="WorkitemCommentsListGetResponseDataItemAttributesText")


@_attrs_define
class WorkitemCommentsListGetResponseDataItemAttributesText:
    """
    Attributes:
        type (Union[Unset, WorkitemCommentsListGetResponseDataItemAttributesTextType]):
        value (Union[Unset, str]):  Example: My text value.
    """

    type: Union[
        Unset, WorkitemCommentsListGetResponseDataItemAttributesTextType
    ] = UNSET
    value: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        value = self.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if type is not UNSET:
            field_dict["type"] = type
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _type = d.pop("type", UNSET)
        type: Union[
            Unset, WorkitemCommentsListGetResponseDataItemAttributesTextType
        ]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = WorkitemCommentsListGetResponseDataItemAttributesTextType(
                _type
            )

        value = d.pop("value", UNSET)

        workitem_comments_list_get_response_data_item_attributes_text_obj = (
            cls(
                type=type,
                value=value,
            )
        )

        workitem_comments_list_get_response_data_item_attributes_text_obj.additional_properties = (
            d
        )
        return (
            workitem_comments_list_get_response_data_item_attributes_text_obj
        )

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> polarion_rest_api_client-1.4.1-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/workitem_comments_list_get_response_data_item_attributes_text.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.workitem_comments_list_get_response_data_item_attributes_text_type import (
    WorkitemCommentsListGetResponseDataItemAttributesTextType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="WorkitemCommentsListGetResponseDataItemAttributesText")


@_attrs_define
class WorkitemCommentsListGetResponseDataItemAttributesText:
    """
    Attributes:
        type_ (Union[Unset, WorkitemCommentsListGetResponseDataItemAttributesTextType]):
        value (Union[Unset, str]):  Example: My text value.
    """

    type_: Union[
        Unset, WorkitemCommentsListGetResponseDataItemAttributesTextType
    ] = UNSET
    value: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> dict[str, Any]:
        type_: Union[Unset, str] = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        value = self.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if type_ is not UNSET:
            field_dict["type"] = type_
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _type_ = d.pop("type", UNSET)
        type_: Union[
            Unset, WorkitemCommentsListGetResponseDataItemAttributesTextType
        ]
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = WorkitemCommentsListGetResponseDataItemAttributesTextType(
                _type_
            )

        value = d.pop("value", UNSET)

        workitem_comments_list_get_response_data_item_attributes_text_obj = (
            cls(
                type_=type_,
                value=value,
            )
        )

        workitem_comments_list_get_response_data_item_attributes_text_obj.additional_properties = (
            d
        )
        return (
            workitem_comments_list_get_response_data_item_attributes_text_obj
        )

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
